# Detector and Interface Management

## Detector Updates
::: fdtdx.fdtd.update.update_detector_states

## Interface Handling
::: fdtdx.fdtd.update.collect_interfaces
::: fdtdx.fdtd.update.add_interfaces
